@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2004 IBM Corporation and others.
+ * Copyright (c) 2004, 2005 IBM Corporation and others.
  * All rights reserved. This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License v1.0
  * which accompanies this distribution, and is available at
@@ -37,6 +37,6 @@ public final class CheatSheetViewerFactory {
 	 * @return a new cheat sheet viewer
 	 */
 	public static ICheatSheetViewer createCheatSheetView() {
-		return new CheatSheetViewer();
+		return new CheatSheetViewer(false);
 	}
 }
